#!/usr/bin/sh

# OS info
os=`uname -s`
ver=`uname -r`
arch=`uname -p`
platform=""
if [ $os = "SunOS" ] ; then
	if [ $ver = "5.10" ] ; then
		platform="sol10"
	fi
fi

# User and group info
user="nagios"
uid=-1
group="nagios"
gid=-1

# Directories
prefix="/opt/nagios"
libexecdir="$prefix/libexec"
sysconfdir="/etc/nagios"

# Binary locations
awk="/usr/bin/awk"
basename="/usr/bin/basename"
cmp="/usr/bin/cmp"
getent="/usr/bin/getent"
grep="/usr/bin/grep"
groupadd="/usr/sbin/groupadd"
pkgadd="/usr/sbin/pkgadd"
pkginfo="/usr/bin/pkginfo"
pkgrm="/usr/sbin/pkgrm"
sed="/usr/bin/sed"
useradd="/usr/sbin/useradd"
usermod="/usr/sbin/usermod"
PATH="/usr/sbin:/usr/bin:/usr/bin"
export PATH

# Shell functions
run_sub() {
	echo "Running '$1'..."

	# Run the command and copy output to installer log
	# Fail file is a portable bourne shell alternative to $PIPESTATUS
	FAILFILE=".fail-$$"
	rm -f "$FAILFILE"
	(eval "$@" 2>&1 || echo $? > "$FAILFILE") | tee -a "$2"
	echo "RESULT=$(cat "$FAILFILE" 2>/dev/null || echo 0)"
	if [ -f "$FAILFILE" ]; then
		cat >&2 <<-EOF

			===================
			INSTALLATION ERROR!
			===================
			Installation step failed - exiting.
			Check for error messages in the install log (install.log).

			If you require assistance in resolving the issue, please include install.log
			in your communications with Nagios XI technical support.

			The script that failed was: '$1'
		EOF
		exit 1
	fi
	rm -f "$FAILFILE"
}

pkgversion() {
	/bin/sh -c "$1" | $grep "VERSION:" | $sed -e 's/,/ /' | $awk '{print $2}'
}

install_sol_pkg() {
	pkgname=$1 # Package name
	pkgsrc=$2  # Package source - usually a file

	echo "Attempting to install $pkgname from $pkgsrc"

	# Initialize local variables
	install=1 # To install or not to install
	scriptresult=0 # We'll assume things will go well

	# Check whether package is installed
	$pkginfo -q $pkgname
	if [ $? -eq 0 ] ; then
		# Package is installed, so see whether we are about to 
		# install the same version
		installed=`pkgversion "$pkginfo -l $pkgname"`
		new=`pkgversion "$pkginfo -l -d $pkgsrc"`
		if [ "$installed" = "$new" ] ; then
			echo "$pkgname package is already installed."
			install=0
		else
			# Some package is installed, but it's not the one we have 
			# to install, so remove it first
			echo "Remove previous instance of $pkgname package"
			$pkgrm $pkgname
			if [ $? -eq 1 ] ; then
				"Unable to remove $pkgname"
				return 1
			fi
		fi
	elif [ $? -ne 1 ] ; then
		echo "Error determining $pkgname package installation status."
		scriptresult=1
	fi

	# Install the package if we should
	if [ $scriptresult -eq 0 -a $install -eq 1 ] ; then
		$pkgadd -d $pkgsrc $pkgname
		if [ $? -ne 0 ] ; then
			return 1
		fi
	fi

	return $scriptresult
}

get_yes_or_no_answer() {
	prompt=$1
	default=$2

	while [ /bin/true ] ; do
		printf "%s " $prompt

		oldstty=`stty -g`
		stty raw -echo
		key=`dd bs=1 count=1 2> /dev/null`
		stty $oldstty 
		case $key in
		[Yy])
			echo $key
			return 0
			;;
		[Nn])
			echo $key
			return 1
			;;
		"
")
			return $default
			;;
		*)
			echo "$key"
			;;
		esac
	done
}
